@@ -1,5 +1,22 @@
 var NAVTREEINDEX12 =
 {
+"classzypp_1_1ChangelogEntry.html#ae5218daf6b6b1ce02fb8d15039dcd4a1":[3,0,10,68,7],
+"classzypp_1_1ChangelogEntry.html#ae5218daf6b6b1ce02fb8d15039dcd4a1":[4,0,7,59,7],
+"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,666],
+"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,68,5],
+"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[4,0,7,59,5],
+"classzypp_1_1CheckAccessDeleted.html":[3,0,10,69],
+"classzypp_1_1CheckAccessDeleted.html":[4,0,7,60],
+"classzypp_1_1CheckAccessDeleted.html#a3656a4238e99904b1144cee6c56e0abe":[3,0,10,69,6],
+"classzypp_1_1CheckAccessDeleted.html#a3656a4238e99904b1144cee6c56e0abe":[4,0,7,60,6],
+"classzypp_1_1CheckAccessDeleted.html#a462b34fd5cbab84297ec05d2c27fd737":[3,0,10,69,9],
+"classzypp_1_1CheckAccessDeleted.html#a462b34fd5cbab84297ec05d2c27fd737":[4,0,7,60,9],
+"classzypp_1_1CheckAccessDeleted.html#a4a07dbf9ea18a007513be6524ccc9d09":[3,0,10,69,5],
+"classzypp_1_1CheckAccessDeleted.html#a4a07dbf9ea18a007513be6524ccc9d09":[4,0,7,60,5],
+"classzypp_1_1CheckAccessDeleted.html#a4d0b49076cc3c8c435c326d6f2db8709":[3,0,10,69,11],
+"classzypp_1_1CheckAccessDeleted.html#a4d0b49076cc3c8c435c326d6f2db8709":[4,0,7,60,11],
+"classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,704],
+"classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,69,14],
 "classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[4,0,7,60,14],
 "classzypp_1_1CheckAccessDeleted.html#a5f230a616a3e858ccea2544a30f27cf9":[3,0,10,69,8],
 "classzypp_1_1CheckAccessDeleted.html#a5f230a616a3e858ccea2544a30f27cf9":[4,0,7,60,8],
@@ -47,7 +64,7 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#a06fd5e79ec7eb31cf9cfa2e3522d0cb3":[4,0,7,61,26],
 "classzypp_1_1CheckSum.html#a1189d7481d7020b7044be58e8a31dad3":[3,0,10,70,36],
 "classzypp_1_1CheckSum.html#a1189d7481d7020b7044be58e8a31dad3":[4,0,7,61,36],
-"classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[3,0,10,804],
+"classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[3,0,10,805],
 "classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[3,0,10,70,46],
 "classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[4,0,7,61,46],
 "classzypp_1_1CheckSum.html#a14394b853d60e56b7e944f8fe07693d7":[3,0,10,70,32],
@@ -68,8 +85,8 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#a37689dd9b4adecf75b5d3799ce312cad":[4,0,7,61,50],
 "classzypp_1_1CheckSum.html#a37aadce213b9860726920f77987ad7eb":[3,0,10,70,42],
 "classzypp_1_1CheckSum.html#a37aadce213b9860726920f77987ad7eb":[4,0,7,61,42],
-"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,802],
-"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,806],
+"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,803],
+"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,807],
 "classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,70,44],
 "classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,70,48],
 "classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[4,0,7,61,44],
@@ -92,7 +109,7 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#a62e775f0977b97938ce4c3898ac1a28b":[4,0,7,61,21],
 "classzypp_1_1CheckSum.html#a717983c8a9a8e0f1013041aaa8226b3a":[3,0,10,70,29],
 "classzypp_1_1CheckSum.html#a717983c8a9a8e0f1013041aaa8226b3a":[4,0,7,61,29],
-"classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[3,0,10,805],
+"classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[3,0,10,806],
 "classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[3,0,10,70,47],
 "classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[4,0,7,61,47],
 "classzypp_1_1CheckSum.html#a82b097c57c3682e29851440cb46b0260":[3,0,10,70,24],
@@ -141,8 +158,8 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#ae2738a3b41c967df7f8189b9cc87d7ff":[4,0,7,61,34],
 "classzypp_1_1CheckSum.html#ae4e10150fabdf9476aa4fc07c846ba4e":[3,0,10,70,0],
 "classzypp_1_1CheckSum.html#ae4e10150fabdf9476aa4fc07c846ba4e":[4,0,7,61,0],
-"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,803],
-"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,807],
+"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,804],
+"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,808],
 "classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,70,45],
 "classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,70,49],
 "classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[4,0,7,61,45],
@@ -187,34 +204,38 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CombinedProgressData.html#a6c252fe6e54d9dc2de5d30c638133030":[4,0,7,68,3],
 "classzypp_1_1CommitPackagePreloader.html":[3,0,10,78],
 "classzypp_1_1CommitPackagePreloader.html":[4,0,7,69],
-"classzypp_1_1CommitPackagePreloader.html#a0fb3464ba924392727afdc8c64274765":[3,0,10,78,14],
-"classzypp_1_1CommitPackagePreloader.html#a0fb3464ba924392727afdc8c64274765":[4,0,7,69,14],
-"classzypp_1_1CommitPackagePreloader.html#a132c006404b500d5204eacf066b947d1":[3,0,10,78,12],
-"classzypp_1_1CommitPackagePreloader.html#a132c006404b500d5204eacf066b947d1":[4,0,7,69,12],
-"classzypp_1_1CommitPackagePreloader.html#a4dccc611d23cfc2d741f8feda0eced42":[3,0,10,78,15],
-"classzypp_1_1CommitPackagePreloader.html#a4dccc611d23cfc2d741f8feda0eced42":[4,0,7,69,15],
-"classzypp_1_1CommitPackagePreloader.html#a548c89a3fca92840db094f6a80562577":[3,0,10,78,8],
-"classzypp_1_1CommitPackagePreloader.html#a548c89a3fca92840db094f6a80562577":[4,0,7,69,8],
-"classzypp_1_1CommitPackagePreloader.html#a5564d6f6ea1ab2b989a01b9b62db6c5d":[3,0,10,78,11],
-"classzypp_1_1CommitPackagePreloader.html#a5564d6f6ea1ab2b989a01b9b62db6c5d":[4,0,7,69,11],
-"classzypp_1_1CommitPackagePreloader.html#a761a4a811869c1e82844b03f980b4ed5":[3,0,10,78,10],
-"classzypp_1_1CommitPackagePreloader.html#a761a4a811869c1e82844b03f980b4ed5":[4,0,7,69,10],
-"classzypp_1_1CommitPackagePreloader.html#a7e1a98f25a40c56affc19f171191fec6":[3,0,10,78,7],
-"classzypp_1_1CommitPackagePreloader.html#a7e1a98f25a40c56affc19f171191fec6":[4,0,7,69,7],
-"classzypp_1_1CommitPackagePreloader.html#a82b33fdb13174e01a2a9f9ef8c4294a8":[3,0,10,78,4],
-"classzypp_1_1CommitPackagePreloader.html#a82b33fdb13174e01a2a9f9ef8c4294a8":[4,0,7,69,4],
-"classzypp_1_1CommitPackagePreloader.html#a911236acbb321a88088380c2b7cff990":[3,0,10,78,3],
-"classzypp_1_1CommitPackagePreloader.html#a911236acbb321a88088380c2b7cff990":[4,0,7,69,3],
-"classzypp_1_1CommitPackagePreloader.html#a967e36afb37146ebf7d07563021a84be":[3,0,10,78,16],
-"classzypp_1_1CommitPackagePreloader.html#a967e36afb37146ebf7d07563021a84be":[4,0,7,69,16],
-"classzypp_1_1CommitPackagePreloader.html#aa9a42323c8ec41ac7f2101d3d56dd5d0":[3,0,10,78,13],
-"classzypp_1_1CommitPackagePreloader.html#aa9a42323c8ec41ac7f2101d3d56dd5d0":[4,0,7,69,13],
-"classzypp_1_1CommitPackagePreloader.html#ab47bbd3cf688f484aaf361b057ccc5ac":[3,0,10,78,6],
-"classzypp_1_1CommitPackagePreloader.html#ab47bbd3cf688f484aaf361b057ccc5ac":[4,0,7,69,6],
-"classzypp_1_1CommitPackagePreloader.html#ac371b05f160b7531586988f64008e0f1":[3,0,10,78,5],
-"classzypp_1_1CommitPackagePreloader.html#ac371b05f160b7531586988f64008e0f1":[4,0,7,69,5],
-"classzypp_1_1CommitPackagePreloader.html#af66ebe06f936fdf089176bd11e31489d":[3,0,10,78,9],
-"classzypp_1_1CommitPackagePreloader.html#af66ebe06f936fdf089176bd11e31489d":[4,0,7,69,9],
+"classzypp_1_1CommitPackagePreloader.html#a0fb3464ba924392727afdc8c64274765":[3,0,10,78,15],
+"classzypp_1_1CommitPackagePreloader.html#a0fb3464ba924392727afdc8c64274765":[4,0,7,69,15],
+"classzypp_1_1CommitPackagePreloader.html#a132c006404b500d5204eacf066b947d1":[3,0,10,78,13],
+"classzypp_1_1CommitPackagePreloader.html#a132c006404b500d5204eacf066b947d1":[4,0,7,69,13],
+"classzypp_1_1CommitPackagePreloader.html#a26ca320f8e35ff4dcd38bb7a48e88e1a":[3,0,10,78,17],
+"classzypp_1_1CommitPackagePreloader.html#a26ca320f8e35ff4dcd38bb7a48e88e1a":[4,0,7,69,17],
+"classzypp_1_1CommitPackagePreloader.html#a4dccc611d23cfc2d741f8feda0eced42":[3,0,10,78,16],
+"classzypp_1_1CommitPackagePreloader.html#a4dccc611d23cfc2d741f8feda0eced42":[4,0,7,69,16],
+"classzypp_1_1CommitPackagePreloader.html#a548c89a3fca92840db094f6a80562577":[3,0,10,78,9],
+"classzypp_1_1CommitPackagePreloader.html#a548c89a3fca92840db094f6a80562577":[4,0,7,69,9],
+"classzypp_1_1CommitPackagePreloader.html#a5564d6f6ea1ab2b989a01b9b62db6c5d":[3,0,10,78,12],
+"classzypp_1_1CommitPackagePreloader.html#a5564d6f6ea1ab2b989a01b9b62db6c5d":[4,0,7,69,12],
+"classzypp_1_1CommitPackagePreloader.html#a761a4a811869c1e82844b03f980b4ed5":[3,0,10,78,11],
+"classzypp_1_1CommitPackagePreloader.html#a761a4a811869c1e82844b03f980b4ed5":[4,0,7,69,11],
+"classzypp_1_1CommitPackagePreloader.html#a7e1a98f25a40c56affc19f171191fec6":[3,0,10,78,8],
+"classzypp_1_1CommitPackagePreloader.html#a7e1a98f25a40c56affc19f171191fec6":[4,0,7,69,8],
+"classzypp_1_1CommitPackagePreloader.html#a82b33fdb13174e01a2a9f9ef8c4294a8":[3,0,10,78,5],
+"classzypp_1_1CommitPackagePreloader.html#a82b33fdb13174e01a2a9f9ef8c4294a8":[4,0,7,69,5],
+"classzypp_1_1CommitPackagePreloader.html#a911236acbb321a88088380c2b7cff990":[3,0,10,78,4],
+"classzypp_1_1CommitPackagePreloader.html#a911236acbb321a88088380c2b7cff990":[4,0,7,69,4],
+"classzypp_1_1CommitPackagePreloader.html#a967e36afb37146ebf7d07563021a84be":[3,0,10,78,18],
+"classzypp_1_1CommitPackagePreloader.html#a967e36afb37146ebf7d07563021a84be":[4,0,7,69,18],
+"classzypp_1_1CommitPackagePreloader.html#aa9a42323c8ec41ac7f2101d3d56dd5d0":[3,0,10,78,14],
+"classzypp_1_1CommitPackagePreloader.html#aa9a42323c8ec41ac7f2101d3d56dd5d0":[4,0,7,69,14],
+"classzypp_1_1CommitPackagePreloader.html#ab47bbd3cf688f484aaf361b057ccc5ac":[3,0,10,78,7],
+"classzypp_1_1CommitPackagePreloader.html#ab47bbd3cf688f484aaf361b057ccc5ac":[4,0,7,69,7],
+"classzypp_1_1CommitPackagePreloader.html#abf56bad65766bbf0095684bb0e3c3b90":[3,0,10,78,3],
+"classzypp_1_1CommitPackagePreloader.html#abf56bad65766bbf0095684bb0e3c3b90":[4,0,7,69,3],
+"classzypp_1_1CommitPackagePreloader.html#ac371b05f160b7531586988f64008e0f1":[3,0,10,78,6],
+"classzypp_1_1CommitPackagePreloader.html#ac371b05f160b7531586988f64008e0f1":[4,0,7,69,6],
+"classzypp_1_1CommitPackagePreloader.html#af66ebe06f936fdf089176bd11e31489d":[3,0,10,78,10],
+"classzypp_1_1CommitPackagePreloader.html#af66ebe06f936fdf089176bd11e31489d":[4,0,7,69,10],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html":[3,0,10,78,0],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html":[4,0,7,69,0],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a04c3030e19e161640b9049dd4cdb29d3":[3,0,10,78,0,2],
@@ -228,26 +249,5 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a1f8c75ed75a90c2a030defe2a4675fb3":[3,0,10,78,0,20],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a1f8c75ed75a90c2a030defe2a4675fb3":[4,0,7,69,0,20],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a30470fad2da5684a30a8efe38d9d8139":[3,0,10,78,0,16],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a30470fad2da5684a30a8efe38d9d8139":[4,0,7,69,0,16],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a35797ac1e7f8f559cdad176099cfed02":[3,0,10,78,0,23],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a35797ac1e7f8f559cdad176099cfed02":[4,0,7,69,0,23],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a5804b49f462d01e8f54bf9f0b5e4916a":[3,0,10,78,0,12],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a5804b49f462d01e8f54bf9f0b5e4916a":[4,0,7,69,0,12],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a862a7a7fa554025a3895155e2fe1de16":[3,0,10,78,0,8],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a862a7a7fa554025a3895155e2fe1de16":[4,0,7,69,0,8],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573":[3,0,10,78,0,0],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573":[4,0,7,69,0,0],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573a1462c350cfd4afb8a50fcc0d408aeb63":[3,0,10,78,0,0,1],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573a1462c350cfd4afb8a50fcc0d408aeb63":[4,0,7,69,0,0,1],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573a43c33d8faea9d356bccfcd7e5820c45d":[3,0,10,78,0,0,0],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573a43c33d8faea9d356bccfcd7e5820c45d":[4,0,7,69,0,0,0],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573a77ba340a558bd1d80afce867d437c3b2":[3,0,10,78,0,0,2],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a88fb135baf1b999e760b21e714d67573a77ba340a558bd1d80afce867d437c3b2":[4,0,7,69,0,0,2],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a8a3c0272b3f54d1552b34bd77343f5dc":[3,0,10,78,0,11],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a8a3c0272b3f54d1552b34bd77343f5dc":[4,0,7,69,0,11],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a945a0bd5b5f6560cec42636cbae6404d":[3,0,10,78,0,19],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a945a0bd5b5f6560cec42636cbae6404d":[4,0,7,69,0,19],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a95f7f30cab7b04300810930b788619bb":[3,0,10,78,0,24],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a95f7f30cab7b04300810930b788619bb":[4,0,7,69,0,24],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a9aa657a5d766c2a6574f63ce375ad966":[3,0,10,78,0,4]
+"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a30470fad2da5684a30a8efe38d9d8139":[4,0,7,69,0,16]
 };
