@@ -1,5 +1,22 @@
 var NAVTREEINDEX7 =
 {
+"classztui_1_1PromptOptions.html#adc18f4f53c1f5d8c42b49a6c5e0c308e":[3,0,9,17,13],
+"classztui_1_1PromptOptions.html#adc18f4f53c1f5d8c42b49a6c5e0c308e":[4,0,6,14,13],
+"classztui_1_1PromptOptions.html#ae47ad0eb28f09a25bed37cef7b50e5a0":[3,0,9,17,18],
+"classztui_1_1PromptOptions.html#ae47ad0eb28f09a25bed37cef7b50e5a0":[4,0,6,14,18],
+"classztui_1_1PromptOptions.html#af62900ca5e6fba19938d92473e1d8761":[3,0,9,17,6],
+"classztui_1_1PromptOptions.html#af62900ca5e6fba19938d92473e1d8761":[4,0,6,14,6],
+"classztui_1_1PropertyTable.html":[3,0,9,18],
+"classztui_1_1PropertyTable.html":[4,0,6,15],
+"classztui_1_1PropertyTable.html#a02e81772366390c16ebbae47fb4fa8f9":[3,0,9,18,9],
+"classztui_1_1PropertyTable.html#a02e81772366390c16ebbae47fb4fa8f9":[4,0,6,15,9],
+"classztui_1_1PropertyTable.html#a048af47e43a2f639312f873b54f7c863":[3,0,9,18,15],
+"classztui_1_1PropertyTable.html#a048af47e43a2f639312f873b54f7c863":[4,0,6,15,15],
+"classztui_1_1PropertyTable.html#a09e9e63bef81eba7ea40510eb3a2100e":[3,0,9,18,13],
+"classztui_1_1PropertyTable.html#a09e9e63bef81eba7ea40510eb3a2100e":[4,0,6,15,13],
+"classztui_1_1PropertyTable.html#a17bbcda13cb4e2772cf6e626788753e0":[3,0,9,18,14],
+"classztui_1_1PropertyTable.html#a17bbcda13cb4e2772cf6e626788753e0":[4,0,6,15,14],
+"classztui_1_1PropertyTable.html#a1b36254d54c7fb28042235113caff5e7":[3,0,9,18,17],
 "classztui_1_1PropertyTable.html#a1b36254d54c7fb28042235113caff5e7":[4,0,6,15,17],
 "classztui_1_1PropertyTable.html#a31b840975862a7fe252a5142e0035725":[3,0,9,18,3],
 "classztui_1_1PropertyTable.html#a31b840975862a7fe252a5142e0035725":[4,0,6,15,3],
@@ -232,22 +249,5 @@ var NAVTREEINDEX7 =
 "classztui_1_1ansi_1_1Color.html#a383a4e3f557a040e02290a902f3377d9":[3,0,9,0,1,15],
 "classztui_1_1ansi_1_1Color.html#a383a4e3f557a040e02290a902f3377d9":[4,0,6,0,1,15],
 "classztui_1_1ansi_1_1Color.html#a45b0cdb96c1939540c6669ff87ff169c":[3,0,9,0,1,13],
-"classztui_1_1ansi_1_1Color.html#a45b0cdb96c1939540c6669ff87ff169c":[4,0,6,0,1,13],
-"classztui_1_1ansi_1_1Color.html#a460ac7f9841b5449bdee6a636d1d0e00":[3,0,9,0,1,27],
-"classztui_1_1ansi_1_1Color.html#a460ac7f9841b5449bdee6a636d1d0e00":[4,0,6,0,1,27],
-"classztui_1_1ansi_1_1Color.html#a46bd7f027ac254f2c3f7520ecd18b7f1":[3,0,9,0,1,9],
-"classztui_1_1ansi_1_1Color.html#a46bd7f027ac254f2c3f7520ecd18b7f1":[4,0,6,0,1,9],
-"classztui_1_1ansi_1_1Color.html#a4dabe8701bfc38cc105780daf0b93ed5":[3,0,9,0,1,38],
-"classztui_1_1ansi_1_1Color.html#a4dabe8701bfc38cc105780daf0b93ed5":[4,0,6,0,1,38],
-"classztui_1_1ansi_1_1Color.html#a615445266dfd53a8040c2b52be3be438":[3,0,9,0,1,14],
-"classztui_1_1ansi_1_1Color.html#a615445266dfd53a8040c2b52be3be438":[4,0,6,0,1,14],
-"classztui_1_1ansi_1_1Color.html#a6e67ea637785f5a90561a71d99eb0ec2":[3,0,9,0,1,32],
-"classztui_1_1ansi_1_1Color.html#a6e67ea637785f5a90561a71d99eb0ec2":[4,0,6,0,1,32],
-"classztui_1_1ansi_1_1Color.html#a6e94fdd65cc00f19233aa8da305a380b":[3,0,9,0,1,8],
-"classztui_1_1ansi_1_1Color.html#a6e94fdd65cc00f19233aa8da305a380b":[4,0,6,0,1,8],
-"classztui_1_1ansi_1_1Color.html#a7218e31d4cf4d7ae1c5e745e9bbcc668":[3,0,9,0,1,30],
-"classztui_1_1ansi_1_1Color.html#a7218e31d4cf4d7ae1c5e745e9bbcc668":[4,0,6,0,1,30],
-"classztui_1_1ansi_1_1Color.html#a723292a94b1770cef1791bdbd5e54090":[3,0,9,0,1,26],
-"classztui_1_1ansi_1_1Color.html#a723292a94b1770cef1791bdbd5e54090":[4,0,6,0,1,26],
-"classztui_1_1ansi_1_1Color.html#a782a2f501892bfd9b899ecdc6ca07053":[3,0,9,0,1,17]
+"classztui_1_1ansi_1_1Color.html#a45b0cdb96c1939540c6669ff87ff169c":[4,0,6,0,1,13]
 };
